@@ -84,7 +84,7 @@ module Win32
     SCHED_S_TASK_HAS_NOT_RUN              = 0x00041303
     SCHED_S_TASK_NOT_SCHEDULED            = 0x00041305
     # HRESULT error codes
-    # http://blogs.msdn.com/b/eldar/archive/2007/04/03/a-lot-of-hresult-codes.aspx
+    # https://blogs.msdn.com/b/eldar/archive/2007/04/03/a-lot-of-hresult-codes.aspx
     # in Ruby, an 0x8XXXXXXX style HRESULT can be resolved to 2s complement
     # by using "0x8XXXXXXX".to_i(16) - - 0x100000000
     SCHED_E_ACCOUNT_INFORMATION_NOT_SET   = -2147216625 # 0x8004130F
@@ -158,6 +158,20 @@ module Win32
 
     MAX_RUN_TIMES = TASK_MAX_RUN_TIMES
 
+    # unfortunately MSTask.h does not specify the limits for any settings
+    # so these were determined with some experimentation
+    # if values too large are written, its suspected there may be internal
+    # limits may be exceeded, corrupting the job
+    # used for max application name and path values
+    MAX_PATH                = 260
+    # UNLEN from lmcons.h is 256
+    # https://technet.microsoft.com/it-it/library/bb726984(en-us).aspx specifies 104
+    MAX_ACCOUNT_LENGTH      = 256
+    # command line max length is limited to 8191, choose something high but still enough that we don't blow out CLI
+    MAX_PARAMETERS_LENGTH   = 4096
+    # in testing, this value could be set to a length of 99999, but saving / loading the task failed
+    MAX_COMMENT_LENGTH      = 8192
+
     # Returns a new TaskScheduler object. If a work_item (and possibly the
     # the trigger) are passed as arguments then a new work item is created and
     # associated with that trigger, although you can still activate other tasks
@@ -196,7 +210,7 @@ module Win32
     # Returns an array of scheduled task names.
     #
     def enum
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
       array = []
 
       @pITS.UseInstance(COM::EnumWorkItems, :Enum) do |pIEnum|
@@ -212,7 +226,7 @@ module Win32
                 name_ptr_ptr = FFI::Pointer.new(:pointer, names_array_ptr)
                 for i in 0 ... count
                   name_ptr_ptr[i].read_com_memory_pointer do |name_ptr|
-                    array << name_ptr.read_arbitrary_wide_string_up_to(256)
+                    array << name_ptr.read_arbitrary_wide_string_up_to(MAX_PATH)
                   end
                 end
               end
@@ -229,7 +243,7 @@ module Win32
     # Activate the specified task.
     #
     def activate(task)
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
       raise TypeError unless task.is_a?(String)
 
       FFI::MemoryPointer.new(:pointer) do |ptr|
@@ -245,7 +259,7 @@ module Win32
     # Delete the specified task name.
     #
     def delete(task)
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
       raise TypeError unless task.is_a?(String)
 
       @pITS.Delete(wide_string(task))
@@ -256,7 +270,7 @@ module Win32
     # Execute the current task.
     #
     def run
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       @pITask.Run
     end
@@ -268,13 +282,16 @@ module Win32
     # file instead. A '.job' extension is recommended but not enforced.
     #
     def save(file = nil)
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
+      raise Error.new(_('Account information must be set on the current task to save it properly.')) if !@account_information_set
 
       reset = true
 
       begin
         @pITask.QueryInstance(COM::PersistFile) do |pIPersistFile|
-          pIPersistFile.Save(wide_string(file), 1)
+          wide_file = wide_string(file)
+          pIPersistFile.Save(wide_file, 1)
+          pIPersistFile.SaveCompleted(wide_file)
         end
       rescue
         reset = false
@@ -286,7 +303,7 @@ module Win32
     # Terminate the current task.
     #
     def terminate
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       @pITask.Terminate
     end
@@ -294,7 +311,7 @@ module Win32
     # Set the host on which the various TaskScheduler methods will execute.
     #
     def machine=(host)
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
       raise TypeError unless host.is_a?(String)
 
       @pITS.SetTargetComputer(wide_string(host))
@@ -311,9 +328,18 @@ module Win32
     # bad. In this case the task is created but a warning is generated and
     # false is returned.
     #
+    # Note that if intending to use SYSTEM, specify an empty user and nil password
+    #
+    # Calling task.set_account_information('SYSTEM', nil) will generally not
+    # work, except for one special case where flags are also set like:
+    # task.flags = Win32::TaskScheduler::TASK_FLAG_RUN_ONLY_IF_LOGGED_ON
+    #
+    # This must be done prior to the 1st save() call for the task to be
+    # properly registered and visible through the MMC snap-in / schtasks.exe
+    #
     def set_account_information(user, password)
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       bool = false
 
@@ -321,16 +347,20 @@ module Win32
         if (user.nil? || user=="") && (password.nil? || password=="")
           @pITask.SetAccountInformation(wide_string(""), FFI::Pointer::NULL)
         else
+          if user.length > MAX_ACCOUNT_LENGTH
+            raise Error.new(_("User has exceeded maximum allowed length %{max}") % { max: MAX_ACCOUNT_LENGTH })
+          end
           user = wide_string(user)
           password = wide_string(password)
           @pITask.SetAccountInformation(user, password)
         end
 
+        @account_information_set = true
         bool = true
       rescue Puppet::Util::Windows::Error => e
         raise e unless e.code == SCHED_E_ACCOUNT_INFORMATION_NOT_SET
 
-        warn 'job created, but password was invalid'
+        warn _('job created, but password was invalid')
       end
 
       bool
@@ -340,8 +370,8 @@ module Win32
     # been associated with the task.
     #
     def account_information
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       # default under certain failures
       user = nil
@@ -350,7 +380,7 @@ module Win32
         FFI::MemoryPointer.new(:pointer) do |ptr|
           @pITask.GetAccountInformation(ptr)
           ptr.read_com_memory_pointer do |str_ptr|
-            user = str_ptr.read_arbitrary_wide_string_up_to(256) if ! str_ptr.null?
+            user = str_ptr.read_arbitrary_wide_string_up_to(MAX_ACCOUNT_LENGTH) if ! str_ptr.null?
           end
         end
       rescue Puppet::Util::Windows::Error => e
@@ -365,8 +395,8 @@ module Win32
     # Returns the name of the application associated with the task.
     #
     def application_name
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       app = nil
 
@@ -374,7 +404,7 @@ module Win32
         @pITask.GetApplicationName(ptr)
 
         ptr.read_com_memory_pointer do |str_ptr|
-          app = str_ptr.read_arbitrary_wide_string_up_to(256) if ! str_ptr.null?
+          app = str_ptr.read_arbitrary_wide_string_up_to(MAX_PATH) if ! str_ptr.null?
         end
       end
 
@@ -384,10 +414,14 @@ module Win32
     # Sets the application name associated with the task.
     #
     def application_name=(app)
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
       raise TypeError unless app.is_a?(String)
 
+      # the application name is written to a .job file on disk, so is subject to path limitations
+      if app.length > MAX_PATH
+        raise Error.new(_("Application name has exceeded maximum allowed length %{max}") % { max: MAX_PATH })
+      end
       @pITask.SetApplicationName(wide_string(app))
 
       app
@@ -396,8 +430,8 @@ module Win32
     # Returns the command line parameters for the task.
     #
     def parameters
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       param = nil
 
@@ -405,7 +439,7 @@ module Win32
         @pITask.GetParameters(ptr)
 
         ptr.read_com_memory_pointer do |str_ptr|
-          param = str_ptr.read_arbitrary_wide_string_up_to(256) if ! str_ptr.null?
+          param = str_ptr.read_arbitrary_wide_string_up_to(MAX_PARAMETERS_LENGTH) if ! str_ptr.null?
         end
       end
 
@@ -417,10 +451,14 @@ module Win32
     # line parameters set it to an empty string.
     #
     def parameters=(param)
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
       raise TypeError unless param.is_a?(String)
 
+      if param.length > MAX_PARAMETERS_LENGTH
+        raise Error.new(_("Parameters has exceeded maximum allowed length %{max}") % { max: MAX_PARAMETERS_LENGTH })
+      end
+
       @pITask.SetParameters(wide_string(param))
 
       param
@@ -429,8 +467,8 @@ module Win32
     # Returns the working directory for the task.
     #
     def working_directory
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       dir = nil
 
@@ -438,7 +476,7 @@ module Win32
         @pITask.GetWorkingDirectory(ptr)
 
         ptr.read_com_memory_pointer do |str_ptr|
-          dir = str_ptr.read_arbitrary_wide_string_up_to(256) if ! str_ptr.null?
+          dir = str_ptr.read_arbitrary_wide_string_up_to(MAX_PATH) if ! str_ptr.null?
         end
       end
 
@@ -448,10 +486,14 @@ module Win32
     # Sets the working directory for the task.
     #
     def working_directory=(dir)
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
       raise TypeError unless dir.is_a?(String)
 
+      if dir.length > MAX_PATH
+        raise Error.new(_("Working directory has exceeded maximum allowed length %{max}") % { max: MAX_PATH })
+      end
+
       @pITask.SetWorkingDirectory(wide_string(dir))
 
       dir
@@ -462,39 +504,41 @@ module Win32
     # and 'unknown'.
     #
     def priority
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
+
+      priority_name = ''
 
       FFI::MemoryPointer.new(:dword, 1) do |ptr|
         @pITask.GetPriority(ptr)
 
         pri = ptr.read_dword
         if (pri & IDLE) != 0
-          priority = 'idle'
+          priority_name = 'idle'
         elsif (pri & NORMAL) != 0
-          priority = 'normal'
+          priority_name = 'normal'
         elsif (pri & HIGH) != 0
-          priority = 'high'
+          priority_name = 'high'
         elsif (pri & REALTIME) != 0
-          priority = 'realtime'
+          priority_name = 'realtime'
         elsif (pri & BELOW_NORMAL) != 0
-          priority = 'below_normal'
+          priority_name = 'below_normal'
         elsif (pri & ABOVE_NORMAL) != 0
-          priority = 'above_normal'
+          priority_name = 'above_normal'
         else
-          priority = 'unknown'
+          priority_name = 'unknown'
         end
       end
 
-      priority
+      priority_name
     end
 
     # Sets the priority of the task. The +priority+ should be a numeric
     # priority constant value.
     #
     def priority=(priority)
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
       raise TypeError unless priority.is_a?(Numeric)
 
       @pITask.SetPriority(priority)
@@ -508,12 +552,12 @@ module Win32
     #
     def new_work_item(task, trigger)
       raise TypeError unless trigger.is_a?(Hash)
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
 
       # I'm working around github issue #1 here.
       enum.each{ |name|
         if name.downcase == task.downcase + '.job'
-          raise Error.new("task '#{task}' already exists")
+          raise Error.new(_("task '%{task}' already exists") % { task: task })
         end
       }
 
@@ -534,6 +578,13 @@ module Win32
         end
       end
 
+      # preload task with the SYSTEM account
+      # empty string '' means 'SYSTEM' per MSDN, so default it
+      # given an account is necessary for creation of a task
+      # note that a user may set SYSTEM explicitly, but that has problems
+      # https://msdn.microsoft.com/en-us/library/windows/desktop/aa381276(v=vs.85).aspx
+      set_account_information('', nil)
+
       @pITask
     end
 
@@ -542,8 +593,8 @@ module Win32
     # Returns the number of triggers associated with the active task.
     #
     def trigger_count
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       count = 0
 
@@ -558,8 +609,8 @@ module Win32
     # Deletes the trigger at the specified index.
     #
     def delete_trigger(index)
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       @pITask.DeleteTrigger(index)
       index
@@ -569,8 +620,8 @@ module Win32
     # current task.
     #
     def trigger(index)
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       trigger = {}
 
@@ -587,8 +638,8 @@ module Win32
     # Sets the trigger for the currently active task.
     #
     def trigger=(trigger)
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
       raise TypeError unless trigger.is_a?(Hash)
 
       FFI::MemoryPointer.new(:word, 1) do |trigger_index_ptr|
@@ -607,8 +658,8 @@ module Win32
     # Adds a trigger at the specified index.
     #
     def add_trigger(index, trigger)
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
       raise TypeError unless trigger.is_a?(Hash)
 
       @pITask.UseInstance(COM::TaskTrigger, :GetTrigger, index) do |pITaskTrigger|
@@ -620,7 +671,7 @@ module Win32
     # must OR the return value to determine the flags yourself.
     #
     def flags
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       flags = 0
 
@@ -635,8 +686,8 @@ module Win32
     # Sets an OR'd value of flags that modify the behavior of the work item.
     #
     def flags=(flags)
-      raise Error.new('No current task scheduler. ITaskScheduler is NULL.') if @pITS.nil?
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No current task scheduler. ITaskScheduler is NULL.')) if @pITS.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       @pITask.SetFlags(flags)
       flags
@@ -646,7 +697,7 @@ module Win32
     # 'ready', 'running', 'not scheduled' or 'unknown'.
     #
     def status
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       st = nil
 
@@ -672,7 +723,7 @@ module Win32
     # Returns the exit code from the last scheduled run.
     #
     def exit_code
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       status = 0
 
@@ -691,7 +742,7 @@ module Win32
     # Returns the comment associated with the task, if any.
     #
     def comment
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       comment = nil
 
@@ -699,7 +750,7 @@ module Win32
         @pITask.GetComment(ptr)
 
         ptr.read_com_memory_pointer do |str_ptr|
-          comment = str_ptr.read_arbitrary_wide_string_up_to(256) if ! str_ptr.null?
+          comment = str_ptr.read_arbitrary_wide_string_up_to(MAX_COMMENT_LENGTH) if ! str_ptr.null?
         end
       end
 
@@ -709,9 +760,13 @@ module Win32
     # Sets the comment for the task.
     #
     def comment=(comment)
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
       raise TypeError unless comment.is_a?(String)
 
+      if comment.length > MAX_COMMENT_LENGTH
+        raise Error.new(_("Comment has exceeded maximum allowed length %{max}") % { max: MAX_COMMENT_LENGTH })
+      end
+
       @pITask.SetComment(wide_string(comment))
       comment
     end
@@ -719,7 +774,7 @@ module Win32
     # Returns the name of the user who created the task.
     #
     def creator
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       creator = nil
 
@@ -727,7 +782,7 @@ module Win32
         @pITask.GetCreator(ptr)
 
         ptr.read_com_memory_pointer do |str_ptr|
-          creator = str_ptr.read_arbitrary_wide_string_up_to(256) if ! str_ptr.null?
+          creator = str_ptr.read_arbitrary_wide_string_up_to(MAX_ACCOUNT_LENGTH) if ! str_ptr.null?
         end
       end
 
@@ -737,9 +792,14 @@ module Win32
     # Sets the creator for the task.
     #
     def creator=(creator)
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
       raise TypeError unless creator.is_a?(String)
 
+      if creator.length > MAX_ACCOUNT_LENGTH
+        raise Error.new(_("Creator has exceeded maximum allowed length %{max}") % { max: MAX_ACCOUNT_LENGTH })
+      end
+
+
       @pITask.SetCreator(wide_string(creator))
       creator
     end
@@ -747,7 +807,7 @@ module Win32
     # Returns a Time object that indicates the next time the task will run.
     #
     def next_run_time
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       time = nil
 
@@ -763,7 +823,7 @@ module Win32
     # nil if the task has never run.
     #
     def most_recent_run_time
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       time = nil
 
@@ -783,7 +843,7 @@ module Win32
     # will run before terminating.
     #
     def max_run_time
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
 
       max_run_time = nil
 
@@ -799,7 +859,7 @@ module Win32
     # before terminating. Returns the value you specified if successful.
     #
     def max_run_time=(max_run_time)
-      raise Error.new('No currently active task. ITask is NULL.') if @pITask.nil?
+      raise Error.new(_('No currently active task. ITask is NULL.')) if @pITask.nil?
       raise TypeError unless max_run_time.is_a?(Numeric)
 
       @pITask.SetMaxRunTime(max_run_time)
@@ -808,14 +868,8 @@ module Win32
 
     # Returns whether or not the scheduled task exists.
     def exists?(job_name)
-      bool = false
-      Dir.foreach("#{ENV['SystemRoot']}/Tasks"){ |file|
-        if File.basename(file, '.job') == job_name
-          bool = true
-          break
-        end
-      }
-      bool
+      # task name comparison is case insensitive
+      tasks.any? { |name| name.casecmp(job_name + '.job') == 0 }
     end
 
     private
@@ -887,6 +941,7 @@ module Win32
       # Ensure that COM reference is decremented properly
       @pITask.Release if @pITask && ! @pITask.null?
       @pITask = nil
+      @account_information_set = false
     end
 
     def populate_trigger(task_trigger, trigger)
@@ -922,14 +977,15 @@ module Win32
             when :TASK_TIME_TRIGGER_ONCE
               # Do nothing. The Type member of the TASK_TRIGGER struct is ignored.
             else
-              raise Error.new("Unknown trigger type #{trigger['trigger_type']}")
+              raise Error.new(_("Unknown trigger type %{type}") % { type: trigger['trigger_type'] })
           end
 
           trigger_struct = COM::TASK_TRIGGER.new(trigger_ptr)
           trigger_struct[:cbTriggerSize] = COM::TASK_TRIGGER.size
-          trigger_struct[:wBeginYear] = trigger['start_year'] || 0
-          trigger_struct[:wBeginMonth] = trigger['start_month'] || 0
-          trigger_struct[:wBeginDay] = trigger['start_day'] || 0
+          now = Time.now
+          trigger_struct[:wBeginYear] = trigger['start_year'] || now.year
+          trigger_struct[:wBeginMonth] = trigger['start_month'] || now.month
+          trigger_struct[:wBeginDay] = trigger['start_day'] || now.day
           trigger_struct[:wEndYear] = trigger['end_year'] || 0
           trigger_struct[:wEndMonth] = trigger['end_month'] || 0
           trigger_struct[:wEndDay] = trigger['end_day'] || 0
@@ -940,7 +996,7 @@ module Win32
           trigger_struct[:rgFlags] = trigger['flags'] || 0
           trigger_struct[:TriggerType] = trigger['trigger_type'] || :TASK_TIME_TRIGGER_ONCE
           trigger_struct[:Type] = trigger_type_union
-          trigger_struct[:wRandomMinutesInterval] = trigger['random_minutes_interval']
+          trigger_struct[:wRandomMinutesInterval] = trigger['random_minutes_interval'] || 0
 
           task_trigger.SetTrigger(trigger_struct)
         end
@@ -988,7 +1044,7 @@ module Win32
         when :TASK_TIME_TRIGGER_ONCE
           trigger['type'] = { 'once' => nil }
         else
-          raise Error.new("Unknown trigger type #{task_trigger[:TriggerType]}")
+          raise Error.new(_("Unknown trigger type %{type}") % { type: task_trigger[:TriggerType] })
       end
 
       trigger
@@ -1002,7 +1058,7 @@ module Win32
 
       public
 
-      # http://msdn.microsoft.com/en-us/library/windows/desktop/aa381811(v=vs.85).aspx
+      # https://msdn.microsoft.com/en-us/library/windows/desktop/aa381811(v=vs.85).aspx
       ITaskScheduler = com::Interface[com::IUnknown,
         FFI::WIN32::GUID['148BD527-A2AB-11CE-B11F-00AA00530503'],
 
@@ -1025,7 +1081,7 @@ module Win32
       TaskScheduler = com::Factory[ITaskScheduler,
         FFI::WIN32::GUID['148BD52A-A2AB-11CE-B11F-00AA00530503']]
 
-      # http://msdn.microsoft.com/en-us/library/windows/desktop/aa380706(v=vs.85).aspx
+      # https://msdn.microsoft.com/en-us/library/windows/desktop/aa380706(v=vs.85).aspx
       IEnumWorkItems = com::Interface[com::IUnknown,
         FFI::WIN32::GUID['148BD528-A2AB-11CE-B11F-00AA00530503'],
 
@@ -1039,7 +1095,7 @@ module Win32
 
       EnumWorkItems = com::Instance[IEnumWorkItems]
 
-      # http://msdn.microsoft.com/en-us/library/windows/desktop/aa381216(v=vs.85).aspx
+      # https://msdn.microsoft.com/en-us/library/windows/desktop/aa381216(v=vs.85).aspx
       IScheduledWorkItem = com::Interface[com::IUnknown,
         FFI::WIN32::GUID['a6b952f0-a4b1-11d0-997d-00aa006887ec'],
 
@@ -1091,7 +1147,7 @@ module Win32
         GetAccountInformation: [[:pointer], :hresult]
       ]
 
-      # http://msdn.microsoft.com/en-us/library/windows/desktop/aa381311(v=vs.85).aspx
+      # https://msdn.microsoft.com/en-us/library/windows/desktop/aa381311(v=vs.85).aspx
       ITask = com::Interface[IScheduledWorkItem,
         FFI::WIN32::GUID['148BD524-A2AB-11CE-B11F-00AA00530503'],
 
@@ -1117,14 +1173,14 @@ module Win32
 
       Task = com::Instance[ITask]
 
-      # http://msdn.microsoft.com/en-us/library/windows/desktop/ms688695(v=vs.85).aspx
+      # https://msdn.microsoft.com/en-us/library/windows/desktop/ms688695(v=vs.85).aspx
       IPersist = com::Interface[com::IUnknown,
         FFI::WIN32::GUID['0000010c-0000-0000-c000-000000000046'],
         # CLSID *
         GetClassID: [[:pointer], :hresult]
       ]
 
-      # http://msdn.microsoft.com/en-us/library/windows/desktop/ms687223(v=vs.85).aspx
+      # https://msdn.microsoft.com/en-us/library/windows/desktop/ms687223(v=vs.85).aspx
       IPersistFile = com::Interface[IPersist,
         FFI::WIN32::GUID['0000010b-0000-0000-C000-000000000046'],
 
@@ -1138,7 +1194,7 @@ module Win32
 
       PersistFile = com::Instance[IPersistFile]
 
-      # http://msdn.microsoft.com/en-us/library/windows/desktop/aa381864(v=vs.85).aspx
+      # https://msdn.microsoft.com/en-us/library/windows/desktop/aa381864(v=vs.85).aspx
       ITaskTrigger = com::Interface[com::IUnknown,
         FFI::WIN32::GUID['148BD52B-A2AB-11CE-B11F-00AA00530503'],
 
@@ -1149,7 +1205,7 @@ module Win32
 
       TaskTrigger = com::Instance[ITaskTrigger]
 
-      # http://msdn.microsoft.com/en-us/library/windows/desktop/aa383620(v=vs.85).aspx
+      # https://msdn.microsoft.com/en-us/library/windows/desktop/aa383620(v=vs.85).aspx
       # The TASK_TRIGGER_TYPE field of the TASK_TRIGGER structure determines
       # which member of the TRIGGER_TYPE_UNION field to use.
       TASK_TRIGGER_TYPE = enum(
@@ -1163,31 +1219,31 @@ module Win32
         :TASK_EVENT_TRIGGER_AT_LOGON, 7         # Ignore the Type field
       )
 
-      # http://msdn.microsoft.com/en-us/library/windows/desktop/aa446857(v=vs.85).aspx
+      # https://msdn.microsoft.com/en-us/library/windows/desktop/aa446857(v=vs.85).aspx
       class DAILY < FFI::Struct
         layout :DaysInterval, :word
       end
 
-      # http://msdn.microsoft.com/en-us/library/windows/desktop/aa384014(v=vs.85).aspx
+      # https://msdn.microsoft.com/en-us/library/windows/desktop/aa384014(v=vs.85).aspx
       class WEEKLY < FFI::Struct
         layout :WeeksInterval, :word,
                :rgfDaysOfTheWeek, :word
       end
 
-      # http://msdn.microsoft.com/en-us/library/windows/desktop/aa381918(v=vs.85).aspx
+      # https://msdn.microsoft.com/en-us/library/windows/desktop/aa381918(v=vs.85).aspx
       class MONTHLYDATE < FFI::Struct
         layout :rgfDays, :dword,
                :rgfMonths, :word
       end
 
-      # http://msdn.microsoft.com/en-us/library/windows/desktop/aa381918(v=vs.85).aspx
+      # https://msdn.microsoft.com/en-us/library/windows/desktop/aa381918(v=vs.85).aspx
       class MONTHLYDOW < FFI::Struct
         layout :wWhichWeek, :word,
                :rgfDaysOfTheWeek, :word,
                :rgfMonths, :word
       end
 
-      # http://msdn.microsoft.com/en-us/library/windows/desktop/aa384002(v=vs.85).aspx
+      # https://msdn.microsoft.com/en-us/library/windows/desktop/aa384002(v=vs.85).aspx
       class TRIGGER_TYPE_UNION < FFI::Union
         layout :Daily, DAILY,
                :Weekly, WEEKLY,
@@ -1195,7 +1251,7 @@ module Win32
                :MonthlyDOW, MONTHLYDOW
       end
 
-      # http://msdn.microsoft.com/en-us/library/windows/desktop/aa383618(v=vs.85).aspx
+      # https://msdn.microsoft.com/en-us/library/windows/desktop/aa383618(v=vs.85).aspx
       class TASK_TRIGGER < FFI::Struct
         layout :cbTriggerSize, :word,            # Structure size.
                :Reserved1, :word,                # Reserved. Must be zero.
